
# Slot: object




URI: [biolink:gene_to_gene_product_relationship_object](https://w3id.org/biolink/vocab/gene_to_gene_product_relationship_object)


## Domain and Range

[GeneToGeneProductRelationship](GeneToGeneProductRelationship.md) &#8594;  <sub>1..1</sub> [GeneProductMixin](GeneProductMixin.md)

## Parents

 *  is_a: [sequence feature relationship➞object](sequence_feature_relationship_object.md)

## Children


## Used by

 * [GeneToGeneProductRelationship](GeneToGeneProductRelationship.md)
